==> digikam-7.0.0.tar.xz: digikam-7.0.0/core/dplugins/bqm/filters/filmgrain/filmgrain.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2010-05-03
 * Description : a batch tool to addd film grain to images.
 *
 * Copyright (C) 2010-2020 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_BQM_FILM_GRAIN_H
#define DIGIKAM_BQM_FILM_GRAIN_H

// Local includes

#include "batchtool.h"
#include "filmgrainsettings.h"

using namespace Digikam;

namespace DigikamBqmFilmGrainPlugin
{

class FilmGrain : public BatchTool
{
    Q_OBJECT

public:

    explicit FilmGrain(QObject* const parent = nullptr);
    ~FilmGrain();

    BatchToolSettings defaultSettings();

    BatchTool* clone(QObject* const parent=nullptr) const { return new FilmGrain(parent); };

    void registerSettingsWidget();

private:

    bool toolOperations();

private Q_SLOTS:

    void slotAssignSettings2Widget();
    void slotSettingsChanged();

private:

    FilmGrainSettings* m_settingsView;
};

} // namespace DigikamBqmFilmGrainPlugin

#endif // DIGIKAM_BQM_FILM_GRAIN_H

==> digikam-7.2.0.tar.xz: digikam-7.2.0/core/dplugins/bqm/filters/filmgrain/filmgrain.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2010-05-03
 * Description : a batch tool to addd film grain to images.
 *
 * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_BQM_FILM_GRAIN_H
#define DIGIKAM_BQM_FILM_GRAIN_H

// Local includes

#include "batchtool.h"
#include "filmgrainsettings.h"

using namespace Digikam;

namespace DigikamBqmFilmGrainPlugin
{

class FilmGrain : public BatchTool
{
    Q_OBJECT

public:

    explicit FilmGrain(QObject* const parent = nullptr);
    ~FilmGrain() override;

    BatchToolSettings defaultSettings() override;

    BatchTool* clone(QObject* const parent=nullptr) const override { return new FilmGrain(parent); };

    void registerSettingsWidget() override;

private:

    bool toolOperations() override;

private Q_SLOTS:

    void slotAssignSettings2Widget() override;
    void slotSettingsChanged() override;

private:

    FilmGrainSettings* m_settingsView;
};

} // namespace DigikamBqmFilmGrainPlugin

#endif // DIGIKAM_BQM_FILM_GRAIN_H
